==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ALongBaseType.h <==
// public final class soot.jimple.parser.node.ALongBaseType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 807798375b1ba50 soot_jimple_parser_node_ALongBaseType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5816fe0bb21d8c7b soot_jimple_parser_node_PBaseType

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseType

#include "soot/jimple/parser/node/PBaseType.h"

#ifndef _JC_soot_jimple_parser_node_ALongBaseType_H_
#define _JC_soot_jimple_parser_node_ALongBaseType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TLong$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ALongBaseType$sub_refs	_jc_soot_jimple_parser_node_ALongBaseType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ALongBaseType$sub_nonrefs	_jc_soot_jimple_parser_node_ALongBaseType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALongBaseType$refs	_jc_soot_jimple_parser_node_ALongBaseType$refs;
typedef struct _jc_soot_jimple_parser_node_ALongBaseType$nonrefs	_jc_soot_jimple_parser_node_ALongBaseType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALongBaseType$object	_jc_soot_jimple_parser_node_ALongBaseType$object;

typedef const struct _jc_soot_jimple_parser_node_ALongBaseType$vmethods	_jc_soot_jimple_parser_node_ALongBaseType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ALongBaseType$vtable	_jc_soot_jimple_parser_node_ALongBaseType$vtable;
typedef const struct _jc_soot_jimple_parser_node_ALongBaseType$vtype	_jc_soot_jimple_parser_node_ALongBaseType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ALongBaseType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *);
extern void _jc_soot_jimple_parser_node_ALongBaseType$method$_init$9ea5740829247a60(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *, struct _jc_soot_jimple_parser_node_TLong$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ALongBaseType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ALongBaseType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *);
extern struct _jc_soot_jimple_parser_node_TLong$object *_jc_soot_jimple_parser_node_ALongBaseType$method$getLong$6b073f7163c8a22c(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *);
extern void _jc_soot_jimple_parser_node_ALongBaseType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ALongBaseType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ALongBaseType$method$setLong$07e97d8687356b88(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *, struct _jc_soot_jimple_parser_node_TLong$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ALongBaseType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseType$method_info$getLong$6b073f7163c8a22c;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseType$method_info$setLong$07e97d8687356b88;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ALongBaseType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *);
	struct _jc_soot_jimple_parser_node_TLong$object	*(*getLong$6b073f7163c8a22c)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setLong$07e97d8687356b88)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *, struct _jc_soot_jimple_parser_node_TLong$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ALongBaseType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseType$vmethods	soot_jimple_parser_node_PBaseType;
	_jc_soot_jimple_parser_node_ALongBaseType$vmethods	soot_jimple_parser_node_ALongBaseType;
};

// Vtype
struct _jc_soot_jimple_parser_node_ALongBaseType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ALongBaseType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALongBaseType$sub_refs {
	struct _jc_soot_jimple_parser_node_TLong$object	*__5flong__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALongBaseType$refs {
    _jc_soot_jimple_parser_node_ALongBaseType$sub_refs	soot_jimple_parser_node_ALongBaseType;
    _jc_soot_jimple_parser_node_PBaseType$sub_refs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALongBaseType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALongBaseType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseType$sub_nonrefs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_ALongBaseType$sub_nonrefs	soot_jimple_parser_node_ALongBaseType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ALongBaseType$object {
	_jc_soot_jimple_parser_node_ALongBaseType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ALongBaseType$vtype	*vtype;
	_jc_soot_jimple_parser_node_ALongBaseType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ALongBaseType$vtype _jc_soot_jimple_parser_node_ALongBaseType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ALongBaseType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ALongBaseType$class_object;

#endif	/* _JC_soot_jimple_parser_node_ALongBaseType_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ALongBaseType.h <==
// public final class soot.jimple.parser.node.ALongBaseType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 807798375b1ba50 soot_jimple_parser_node_ALongBaseType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5816fe0bb21d8c7b soot_jimple_parser_node_PBaseType

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseType

#include "soot/jimple/parser/node/PBaseType.h"

#ifndef _JC_soot_jimple_parser_node_ALongBaseType_H_
#define _JC_soot_jimple_parser_node_ALongBaseType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TLong$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ALongBaseType$sub_refs	_jc_soot_jimple_parser_node_ALongBaseType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ALongBaseType$sub_nonrefs	_jc_soot_jimple_parser_node_ALongBaseType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALongBaseType$refs	_jc_soot_jimple_parser_node_ALongBaseType$refs;
typedef struct _jc_soot_jimple_parser_node_ALongBaseType$nonrefs	_jc_soot_jimple_parser_node_ALongBaseType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALongBaseType$object	_jc_soot_jimple_parser_node_ALongBaseType$object;

typedef const struct _jc_soot_jimple_parser_node_ALongBaseType$vmethods	_jc_soot_jimple_parser_node_ALongBaseType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ALongBaseType$vtable	_jc_soot_jimple_parser_node_ALongBaseType$vtable;
typedef const struct _jc_soot_jimple_parser_node_ALongBaseType$vtype	_jc_soot_jimple_parser_node_ALongBaseType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ALongBaseType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALongBaseType$method$_init$9ea5740829247a60(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *, struct _jc_soot_jimple_parser_node_TLong$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ALongBaseType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ALongBaseType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TLong$object *_jc_soot_jimple_parser_node_ALongBaseType$method$getLong$6b073f7163c8a22c(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALongBaseType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALongBaseType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALongBaseType$method$setLong$07e97d8687356b88(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *, struct _jc_soot_jimple_parser_node_TLong$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ALongBaseType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseType$method_info$getLong$6b073f7163c8a22c;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseType$method_info$setLong$07e97d8687356b88;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ALongBaseType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TLong$object	*(*getLong$6b073f7163c8a22c)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setLong$07e97d8687356b88)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *, struct _jc_soot_jimple_parser_node_TLong$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ALongBaseType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseType$vmethods	soot_jimple_parser_node_PBaseType;
	_jc_soot_jimple_parser_node_ALongBaseType$vmethods	soot_jimple_parser_node_ALongBaseType;
};

// Vtype
struct _jc_soot_jimple_parser_node_ALongBaseType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ALongBaseType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALongBaseType$sub_refs {
	struct _jc_soot_jimple_parser_node_TLong$object	*__5flong__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALongBaseType$refs {
    _jc_soot_jimple_parser_node_ALongBaseType$sub_refs	soot_jimple_parser_node_ALongBaseType;
    _jc_soot_jimple_parser_node_PBaseType$sub_refs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALongBaseType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALongBaseType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseType$sub_nonrefs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_ALongBaseType$sub_nonrefs	soot_jimple_parser_node_ALongBaseType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ALongBaseType$object {
	_jc_soot_jimple_parser_node_ALongBaseType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ALongBaseType$vtype	*vtype;
	_jc_soot_jimple_parser_node_ALongBaseType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ALongBaseType$vtype _jc_soot_jimple_parser_node_ALongBaseType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ALongBaseType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ALongBaseType$class_object;

#endif	/* _JC_soot_jimple_parser_node_ALongBaseType_H_ */
